/* Copyright (c) 2012-2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Local includes
#include "BoogerRadioButton.h"
#include "BoogerSpinBox.h"
#include "ScoreDialog.h"

// Qt includes
#include <QDebug>
#include <QApplication>

BoogerRadioButton::BoogerRadioButton(QWidget *parent, BoogerSpinBox *spinBox)
    : QRadioButton(parent), m_spinBox(spinBox)
{
}

void BoogerRadioButton::wheelEvent(QWheelEvent *event)
{
    QRadioButton::wheelEvent(event);
    if (isChecked()) {
        QApplication::sendEvent(m_spinBox, event);
    }
}

void BoogerRadioButton::mousePressEvent(QMouseEvent *event)
{
    if (event->button() == Qt::RightButton) {
        setChecked(true);
        emit(clicked());
        showScoreDialog();
    } else {
        QRadioButton::mousePressEvent(event);
    }
}

void BoogerRadioButton::mouseDoubleClickEvent(QMouseEvent *)
{
    if (m_spinBox->isEnabled()) {
        showScoreDialog();
    }
}

void BoogerRadioButton::showScoreDialog()
{
    ScoreDialog scoreDialog(this, m_spinBox);
    scoreDialog.exec();
}
