/* Copyright (c) 2012-2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Local includes
#include "BoogerWidget.h"
#include "BoogerSpinBox.h"
#include "BoogerRadioButton.h"

// Qt includes
#include <QDebug>
#include <QGridLayout>
#include <QLabel>
#include <QCheckBox>
#include <QApplication>
#include <QStyle>

BoogerWidget::BoogerWidget(QWidget *parent, int booger, int boogersPerRound, int boogerScore)
    : QWidget(parent), m_boogerScore(boogerScore)
{
    setAutoFillBackground(false);

    QGridLayout *layout = new QGridLayout(this);
    QLabel *boogerCount = new QLabel;
    boogerCount->setText(QString::fromUtf8("<b>%1</b>").arg(
                                           tr("%1. Bobbl").arg(QString::number(booger))));
    layout->addWidget(boogerCount, 0, 0, 1, 3);

    m_boogerAborted = new QPushButton;
    m_boogerAborted->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
    m_boogerAborted->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Minimum);
    m_boogerAborted->setCheckable(true);
    m_boogerAborted->setToolTip(tr("Markiert den Bobbl als abgebrochen."));
    layout->addWidget(m_boogerAborted, 1, 0, 2, 1);
    connect(m_boogerAborted, &QCheckBox::clicked, this, &BoogerWidget::setBoogerAborted);
    m_boogerAborted->hide();

    for (int i = 1; i <= 2; i++) {
        layout->addWidget(new QLabel(tr("Paar %1").arg(QString::number(i))), i, 1);

        m_score[i] = new BoogerSpinBox;
        if (i == 1) {
            m_score[i]->setMaximum(m_boogerScore - 1);
        } else {
            m_score[i]->setMaximum(m_boogerScore);
        }
        layout->addWidget(m_score[i], i, 2);

        if (booger == boogersPerRound) {
            connect(m_score[i], &BoogerSpinBox::enterPressed,
                    this, &BoogerWidget::emitEnterPressed);
        }

        m_booger[i] = new BoogerRadioButton(this, m_score[i]);
        layout->addWidget(m_booger[i], i, 3);
        connect(m_booger[i], &QRadioButton::clicked, this, &BoogerWidget::toggleScore);
    }

    m_booger[1]->setChecked(true);
    m_score[2]->setValue(m_boogerScore);
    m_score[2]->setEnabled(false);
}

void BoogerWidget::toggleScore()
{
    for (int i = 1; i <= 2; i++) {
        if (m_booger[i]->isChecked()) {
            m_score[i]->setMaximum(m_boogerScore - 1);
            m_score[i]->setValue(0);
            m_score[i]->setEnabled(true);
            m_score[i]->setFocus();
            m_score[i]->selectAll();
        } else {
            m_score[i]->setMaximum(m_boogerScore);
            m_score[i]->setValue(m_boogerScore);
            m_score[i]->setEnabled(false);
        }
    }
}

int BoogerWidget::score(int pair)
{
    return m_score[pair]->value();
}

void BoogerWidget::emitEnterPressed()
{
    emit enterPressed();
}

void BoogerWidget::setScore(int pair1Score, int pair2Score)
{
    if (pair1Score == m_boogerScore) {
        m_booger[2]->setChecked(true);
    } else {
        m_booger[1]->setChecked(true);
    }
    toggleScore();
    m_score[1]->setValue(pair1Score);
    m_score[2]->setValue(pair2Score);
}

void BoogerWidget::abortRound(int state)
{
    m_boogerAborted->setChecked(state == true);
    m_boogerAborted->setVisible(state);
    setBoogerAborted();
}

void BoogerWidget::setBoogerAborted()
{
    if (m_boogerAborted->isChecked()) {
        for (int i = 1; i <= 2; i++) {
            m_booger[i]->hide();
            m_score[i]->setEnabled(true);
            m_score[i]->setValue(0);
            m_score[i]->setMaximum(m_boogerScore - 1);
        }
        m_score[1]->setFocus();
        m_score[1]->selectAll();
    } else {
        m_booger[1]->show();
        m_booger[2]->show();
        m_booger[1]->setChecked(true);
        toggleScore();
    }
}
