/* Copyright (c) 2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Local includes
#include "ExpandingLabel.h"

// Qt includes
#include <QDebug>

ExpandingLabel::ExpandingLabel(QWidget *parent) : QLabel(parent)
{
    setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
    setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
    setMinimumHeight(15);
}

void ExpandingLabel::resizeText()
{
    QString text = this->text();
    if (text.isEmpty()) {
        return;
    }

    QRect labelSpace = contentsRect();
    QFont font = this->font();

    int size = 1;
    while (true) {
        font.setPointSize(size);
        QFontMetrics fontMetrics(font);
        QRect targetSpace = fontMetrics.boundingRect(text);
        if (targetSpace.height() >= labelSpace.height()
            || targetSpace.width() >= labelSpace.width()) {
            break;
        }
        size++;
    }

    font.setPointSize(--size);
    setFont(font);
}

void ExpandingLabel::resizeEvent(QResizeEvent *event)
{
    QLabel::resizeEvent(event);
    resizeText();
}
