/* Copyright (c) 2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Local includes
#include "ScoreDialog.h"

// Qt includes
#include <QDebug>
#include <QGridLayout>
#include <QPushButton>
#include <QSpinBox>
#include <QCursor>

namespace {
const QString NUMBERBUTTONSTYLE = QString::fromUtf8(
    "QPushButton { border: none; border-radius: 4px; padding:0.5em } "
    "QPushButton:hover { border: 1px solid palette(highlight); }"
);
}

ScoreDialog::ScoreDialog(QWidget *parent, QSpinBox *spinBox)
    : QDialog(parent), m_spinBox(spinBox)
{
    setWindowFlags(Qt::Tool | Qt::FramelessWindowHint);
    setStyleSheet(QString::fromUtf8("background-color: white; border: 1px solid gray;"));

    QGridLayout *layout = new QGridLayout(this);

    int maximumRows;
    if (m_spinBox->maximum() <= 30) {
        maximumRows = 5;
    } else {
        maximumRows = 10;
    }

    int row = -1;
    int score = -1;
    while (true) {
        row++;
        for (int column = 0; column < maximumRows; column++) {
            score++;
            if (score > m_spinBox->maximum()) {
                move(QCursor::pos());
                return;
            }

            QPushButton *scoreButton = new QPushButton(QString::number(score));
            scoreButton->setStyleSheet(NUMBERBUTTONSTYLE);
            scoreButton->setProperty("score", QVariant(score));
            layout->addWidget(scoreButton, row, column);
            connect(scoreButton, &QPushButton::clicked,
                    this, [=]() { this->scoreClicked(scoreButton->property("score")); });
        }
    }
}

void ScoreDialog::scoreClicked(const QVariant &score)
{
    m_spinBox->setFocus();
    m_spinBox->setValue(score.toInt());
    m_spinBox->selectAll();
    accept();
}
