/* Copyright (c) 2012-2018 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Local includes
#include "TableDelegate.h"
#include "DefinedCharacters.h"

// Qt includes
#include <QPainter>
#include <QKeyEvent>
#include <QDebug>
#include <QLineEdit>

TableDelegate::TableDelegate(QObject *parent, HighlightMode highlightMode)
    : QStyledItemDelegate(parent), m_highlightMode(highlightMode)
{
}

void TableDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
                          const QModelIndex &index) const
{
    QStyledItemDelegate::paint(painter, option, index);

    if (index.row() == 0) {
        return;
    }

    if (m_highlightMode == HighlightMode::evenRows) {
        if (index.row() % 2 != 0) {
            return;
        }
    }

    painter->setPen(QColor(170, 170, 170));
    painter->drawLine(option.rect.topLeft(), option.rect.topRight());
}

bool TableDelegate::editorEvent(QEvent *event, QAbstractItemModel *model,
                                const QStyleOptionViewItem &, const QModelIndex &index)
{
    if (event->type() == QEvent::MouseButtonDblClick) {
        m_originalData = index.data().toString();
        m_editData = m_originalData;
        m_editData.remove(MARKER_CHARACTER);
        model->setData(index, QVariant(m_editData));
    }
    return false;
}

void TableDelegate::setModelData(QWidget *editor, QAbstractItemModel *, const QModelIndex &) const
{
    QString enteredData = dynamic_cast<QLineEdit *>(editor)->text().simplified();
    if (enteredData.isEmpty() || enteredData == m_originalData || enteredData == m_editData) {
        return;
    }

    if (m_originalData.startsWith(MARKER_CHARACTER)) {
        enteredData = MARKER_CHARACTER + enteredData;
    } else if (m_originalData.endsWith(MARKER_CHARACTER)) {
        enteredData += MARKER_CHARACTER;
    }
    emit editEntered(m_originalData, enteredData);
}
